Publications - Carnegie Endowment for International Peace

# Carnegie Endowment for International Peace

- Follow Carnegie
- Search
- Global Resources

- Research
- Experts
- Programs
- Events
- Topics

## Publications

### Wagging the Plutonium Dog: Japanese Domestic Politics and Its International Security Implications

Japan has pledged not to produce more plutonium than it can consume. Serious questions are emerging, however, about whether it can uphold this commitment.

Browse Titles
Publication Type
Author
Publication Date
Issue Area
Regional Focus
Program

### Books and Reports from Carnegie

- ##### Governing Cyberspace: A Road Map for Transatlantic Leadership

- ##### Strategic Asia 2015-16: Foundations of National Power in the Asia-Pacific

- ##### WTO Accessions and Trade Multilateralism

- ##### Wagging the Plutonium Dog: Japanese Domestic Politics and Its International Security Implications

- ##### Perception and Misperception in American and Chinese Views of the Other

- ##### The Puzzle of Non-Western Democracy

1 | 2 | 3 | 4 | 5... 511

### Latest Analysis

- Op-Ed

  ##### Decoding Rawalpindi

  Christophe Jaffrelot January 29, 2016 Indian Express

  Does Masood Azhar’s “protective custody” reflect a new policy at the top of the Pakistan army?

- TV/Radio Broadcast

  ##### Gender and Politics in the Middle East

  Marc Lynch, Lindsay Benstead January 28, 2016 Project on Middle East Political Science

  Across the Middle East, large gender gaps exist in levels of political activity, voter turnout, and the likelihood of being elected.

- TV/Radio Broadcast

  ##### Egypt Five Years Beyond the Uprising

  Michele Dunne January 28, 2016 BYURadio

  Years of unrest in Egypt have possibly left the country in a worse position than it was before the Arab Spring.

- Article

  ##### Nuclear Energy’s Future in the Middle East and North Africa

  Carole Nakhle January 28, 2016

  As a number of countries in the Middle East and North Africa seek to meet their growing energy needs, they are forced to weigh the highly contested costs and benefits of nuclear power.

- Op-Ed

  ##### Look Homeward, Democracy Promoter

  Thomas Carothers January 27, 2016 Foreign Policy

  Deficiencies of democratic governance in the United States raise questions about its efforts to promote democracy abroad. U.S. democracy aid organizations should begin working to strengthen democracy at home.

- Op-Ed

  ##### Raja-Mandala: A Most Exceptional Friendship

  C. Raja Mohan January 26, 2016 Indian Express

  The participation of French troops in the Republic Day parade marks the emergence of France as India’s most trusted international partner.

- Article

  ##### Luxembourg, Europe’s Bellwether

  Caroline de Gruyter January 26, 2016

  European integration has made Luxembourg prosperous. But at the same time, the country’s ailments are often signs of a broader European malaise.

- Interview

  ##### India’s Newest Think Tank Chief Talks Global Leadership

  C. Raja Mohan January 26, 2016 Devex

  The Indian economy is globalized, and the policymaking has become a lot more complex.

- Op-Ed

  ##### How Much Should the United States Still Care About Central Asia?

  Richard Sokolsky, Paul Stronski January 25, 2016 EurasiaNet

  Central Asian states have a strong interest in maintaining friendly ties with the United States. This geopolitical desire creates meaningful opportunities for U.S. engagement in the near term, and for advancing more modest interests in the years ahead.

- Op-Ed

  ##### The End of an Era … for White Males

  David Rothkopf January 25, 2016 Foreign Policy

  The status quo of the past several millennia is going to undergo a profound change.

- ##### Will China’s New “Supply-Side” Reforms Help China?

  Michael Pettis January 25, 2016 China Financial Markets

  China is embarking on ambitious economic reforms to boost its growth prospects. What is the rationale behind these new reforms and what are the prospects for their success?

- Paper

  ##### U.S. Policy Toward Central Asia 3.0

  Eugene Rumer, Richard Sokolsky, Paul Stronski January 25, 2016

  Major geopolitical shifts and internal dynamics are setting the stage for possible increased great-power competition in Central Asia between Russia and China at a time when the region is becoming less hospitable to the projection of U.S. power and to the promotion of democracy.

- ##### Merkel’s Miscalculations in the Refugee Crisis

  Judy Dempsey January 25, 2016 Deutsche Welle German

  As Europe struggles to find a solution to the refugee crisis, Angela Merkel seems to have very few allies. Are EU leaders turning their backs on Germany?

- Op-Ed

  ##### Did Sisi Save Egypt?

  Nathan Brown, Yasser El-Shimy January 25, 2016 Foreign Affairs

  In the military’s view, Egypt has not met the fate of Syria or Libya, and that by itself is an accomplishment worth celebrating. Politics should and must wait.

- Op-Ed

  ##### Low Oil Prices Today May Not Mean Low Investment Tomorrow

  Carole Nakhle January 22, 2016 Geopolitical Information Services

  The relationship between oil prices, investment and future supply is not so straightforward, and international organizations warn of a major price spike in the future.

- Article

  ##### Chasing Egypt’s Economic Tail

  Yezid Sayigh January 21, 2016 عربي

  The Egyptian president’s central role in economic policy making is unlikely to deliver on the intended goals and could exacerbate existing problems—or generate new ones.

- Op-Ed

  ##### Maintaining Peace Across Taiwan Strait Can Benefit All

  Douglas H. Paal January 21, 2016 China Daily

  The elections in Taiwan have the potential to lead to strains between the United States, Chinese mainland, and Taiwan for the first time in over seven years.

- Op-Ed

  ##### Analysis: How Can War-Torn Yemen Find Peace?

  Farea Al-Muslimi January 21, 2016 Al Jazeera

  With the war in Yemen having no clear goals, the various players in the country must invest in peace for the conflict to end.

- TV/Radio Broadcast

  ##### Does Merkel Have a Plan B?

  Judy Dempsey January 21, 2016 Deutsche Welle

  The German chancellor’s open-door policy toward the refugees is a challenge to her leadership. As public debate gets harsher in Germany, will Angela Merkel opt for a plan B?

- TV/Radio Broadcast

  ##### Egypt’s Revolution

  Marc Lynch, Michael Hanna, Thanassis Cambanis January 21, 2016 Project on Middle East Political Science

  As the anniversary of Egypt’s January 25th revolution approaches, the direction of the country remains uncertain.

1 | 2 | 3 | 4 | 5... 511

##### Twitter

@CarnegieEndow
@CarnegieEndow

### Sign up for Carnegie Email

Personal Information E-mail *

#### Strategic Europe

- ##### Letter From Jerusalem

  January 29, 2016

- ##### Russia’s Manipulation of Germany’s Refugee Problems

  January 28, 2016

- ##### Judy Asks: Will Turkey Help Europe on Refugees?

  January 27, 2016

More from Strategic Europe >
Download the app

Stay connected to Judy Dempsey's Strategic Europe with a new smartphone app for Android and iOS devices

- Available on the App Store
- Get it on Google Play

#### Sada

- ##### A Silver Lining in the Nidaa Tounes Split

  January 29, 2016 Scott Williamson

- ##### Egypt’s Protests by the Numbers

  January 29, 2016 Amy Austin Holmes, Hussein Baoumi

- ##### Egypt’s Natural Gas Crisis

  January 21, 2016 Brendan Meighan

More from Sada >
Download the app

Stay connected to Sada with a new smartphone app for Android and iOS devices

- Available on the App Store
- Get it on Google Play

#### Carnegie.ru

- ##### Kadyrov’s Calculated Provocation

  Andrey Pertsev January 27, 2016

- ##### The Russian Oil Industry in the Era of Cheap Crude

  Mikhail Krutikhin January 26, 2016

- ##### Russia’s Waiting Room

  Andrei Kolesnikov January 22, 2016

More from Carnegie.ru >
Download the app

- Available on the App Store
- Get it on Google Play

#### Syria in Crisis

- ##### The Road to Geneva: the Who, When, and How of Syria’s Peace Talks

  January 29, 2016 Aron Lund

- ##### Rebels in Northwestern Syria Buckle under Russian Bombardment

  January 25, 2016 Aron Lund

- ##### Most Popular Texts on Syria in Crisis in 2015

  January 7, 2016 Aron Lund

More from Syriain Crisis >
Download the app

Stay connected to Syria in Crisis with a new smartphone app for Android and iOS devices

- Available on the App Store
- Get it on Google Play

Download the app

Stay connected to the Global Think Tank with Carnegie's smartphone app for Android and iOS devices

- Available on the App Store
- Get it on Google Play

- Connect with Us
- Privacy Statement
- Help Desk
- Support The Global Think Tank

Carnegie Endowment for International Peace
1779 Massachusetts Avenue NW Washington, DC 20036-2103 Phone: 202 483 7600 Fax: 202 483 1840 Contact By Email
© 2016 All Rights Reserved
Please note...

You are leaving the website for the Carnegie-Tsinghua Center for Global Policy and entering a website for another of Carnegie's global centers.

请注意...

你将离开清华—卡内基中心网站，进入卡内基其他全球中心的网站。